

uniform sampler2D optTex;
uniform sampler2D backbuffer;
uniform vec2 resolution;
uniform vec2 mouse;
uniform float lowFreq;
uniform float time;

uniform float value0;
uniform float value1;
uniform float value2;
uniform float value3;

void main() {
  vec2 pos = vec2(0.5, 0.5) - gl_FragCoord.xy / resolution.xy;
  vec2 aspect = resolution.x / resolution.y;
  pos.x *= aspect;
  vec2 tex;

  vec3 eye = vec3(0.0, 0.0, -5.0);
  vec3 ray = normalize(vec3(pos, 0.0) - eye);

  float zd = 30.0;
  float theta = 1.5 * time;

  float X = (eye.z - zd) / (sin(theta) / cos(theta) - ray.z / ray.x);
  float Z = (ray.z / ray.x) * X + eye.z;
  float Y = ray.y * (Z - eye.z);

  vec3 uv = vec3(cos(theta), 0.0, sin(theta));
  vec3 vv = vec3(0.0, 1.0, 0.0);
  vec3 p = vec3(X, Y, Z) - vec3(0.0, 0.0, zd);
  float u = dot(uv, p);
  float v = dot(vv, p);

  float size = 3.0;
  float blur = 0.7;
  if (abs(u) > size || abs(v) > size) {
    gl_FragColor = blur * texture2D(backbuffer, gl_FragCoord.xy / resolution.xy);
    return;
  }

  u = (u + size) / (2.0 * size);
  v = (v + size) / (2.0 * size);

  float w = 0.3;
  if (cos(theta) < 0.0)
    w = 1.0;
  
  gl_FragColor =  (1.0 - blur) * texture2D(optTex, vec2(u, v)) * w + blur * texture2D(backbuffer, gl_FragCoord.xy / resolution.xy);
}
